@@ -5,9 +5,9 @@
 
 ; (SETQ SAVENO 2550) 
 (DEFPROP $\| %\| VERB) 
-(DEFPROP $\| &\| OP) 
-(DEFPROP &\| $\| OPR) 
-(ADD2LNC (QUOTE &\|) $PROPS) 
+(DEFPROP $\| "|" OP) 
+(putopr "|" '$\|)
+(ADD2LNC (QUOTE "|") $PROPS) 
 (DEFPROP $\| DIMENSION-infix DIMENSION) 
 (DEFPROP $\| (#\Space #\| #\Space) DISSYM) 
 (DEFPROP $\| 120 LBP) 
@@ -30,9 +30,9 @@ $EXT101 (($COEFF SIMP) $EXT103 (($CARTAN_BASIS SIMP ARRAY) $I)))
 (ADD2LNC (QUOTE (($\|) $V $F)) $FUNCTIONS) 
 (DEFPROP %\| $\| NOUN) 
 (DEFPROP $~ %~ VERB) 
-(DEFPROP $~ &~ OP) 
-(DEFPROP &~ $~ OPR) 
-(ADD2LNC (QUOTE &~) $PROPS) 
+(DEFPROP $~ "~" OP) 
+(putopr "~" '$~)
+(ADD2LNC (QUOTE "~") $PROPS) 
 (DEFPROP $~ DIMENSION-infix DIMENSION) 
 (DEFPROP $~ (#\Space #\~ #\Space) DISSYM) 
 (DEFPROP $~ 140 LBP) 
@@ -71,7 +71,7 @@ NIL 1 NIL ((MPROGN SIMP) ((MSETQ SIMP) $EXT103 (($EXPAND SIMP)
  (($EDIT SIMP) $EXT104)) ((MSETQ SIMP) $CARTAN_DIM $EXTDIM) ((MCOND SIMP) 
 ((MEQUAL SIMP) $EXT105 0) ((MSETQ SIMP) $EXT101 ((MPLUS SIMP) $EXT101
  ((MTIMES SIMP) $EXT104 (($CARTAN_BASIS SIMP ARRAY) $I)))) T ((MCOND SIMP)
- ((MEQUAL SIMP) (($INPART SIMP) $EXT105 0) &+) ((MSETQ SIMP) $EXT101
+ ((MEQUAL SIMP) (($INPART SIMP) $EXT105 0) "+") ((MSETQ SIMP) $EXT101
  ((MPLUS SIMP) $EXT101 (($MULTTHRU SIMP) ((MTIMES SIMP) $EXT105
  (($CARTAN_BASIS SIMP ARRAY) $I))))) T ((MSETQ SIMP) $EXT101 ((MPLUS SIMP)
  $EXT101 ((MTIMES SIMP) $EXT105 (($CARTAN_BASIS SIMP ARRAY) $I))))))) 
