@@ -21,35 +21,34 @@
 (defmfun msetchk (x y)
 ;; Redefine msetchk to protect pre_eval_functions and post_eval_functions
 ;; from improper assignments
-  (cond ((memq x '(*read-base* *print-base*))
-	 (cond #-nil ((eq y 'roman))
+  (cond ((member x '(*read-base* *print-base*) :test #'eq)
+	 (cond ((eq y 'roman))
 	       ((or (not (fixnump y)) (< y 2) (> y 35)) (mseterr x y))
-	       ((eq x '*read-base*)
-		#+maclisp (if (< y 11) (sstatus + nil) (sstatus + t)))))
-	((memq x '($linel $fortindent $gensumnum $fpprintprec $floatwidth
-		   $parsewindow $ttyintnum))
+	       ((eq x '*read-base*))))
+	((member x '($linel $fortindent $gensumnum $fpprintprec $floatwidth
+		   $parsewindow $ttyintnum) :test #'eq)
 	 (if (not (fixnump y)) (mseterr x y))
-	 ;;	#+MacLisp
-	 ;;	(WHEN (EQ X '$LINEL)
-	 ;;	  (LINEL T (LINEL NIL Y))
-	 ;;	  (DOLIST (FILE OUTFILES) (LINEL FILE Y))
-	 ;;	  (SETQ LINEL Y))
-	 (if (eq x '$linel) (setq linel y))
-	 (cond ((and (memq x '($fortindent $gensumnum $floatwidth $ttyintnum)) (< y 0))
+         (if (eq x '$linel)
+             (cond ((not (and (> y 0)       ; at least one char per line
+                              (< y 10001))) ; arbitrary chosen big value
+                    (mseterr x y))
+                   (t
+                    (setq linel y))))
+	 (cond ((and (member x '($fortindent $gensumnum $floatwidth $ttyintnum) :test #'eq) (< y 0))
 		(mseterr x y))
 	       ((and (eq x '$parsewindow) (< y -1)) (mseterr x y))
 	       ((and (eq x '$fpprintprec) (or (< y 0) (= y 1))) (mseterr x y))))
-	((memq x '($genindex $optimprefix)) (if (not (symbolp y)) (mseterr x y)))
+	((member x '($genindex $optimprefix) :test #'eq) (if (not (symbolp y)) (mseterr x y)))
 	((eq x '$dotassoc) (cput 'mnctimes y 'associative))
 	((eq x 'modulus)
 	 (cond ((null y))
 	       ((integerp y)
-		(if (or (not (primep y)) (zl-member y '(1 0 -1)))
+		(if (or (not (primep y)) (member y '(1 0 -1) :test #'equal))
 		    (mtell "Warning: `modulus' being set to ~:M, a non-prime.~%" y)))
 	       (t (mseterr x y))))
 	((eq x '$setcheck)
-	 (if (not (or (memq y '($all t nil)) ($listp y))) (mseterr x y)))
-	((eq x '$gcd) (if (not (or (null y) (memq y *gcdl*))) (mseterr x y)))
+	 (if (not (or (member y '($all t nil) :test #'eq) ($listp y))) (mseterr x y)))
+	((eq x '$gcd) (if (not (or (null y) (member y *gcdl* :test #'eq))) (mseterr x y)))
 	((eq x '$ratvars)
 	 (if ($listp y) (apply #'$ratvars (cdr y)) (mseterr x y)))
 	((eq x '$ratfac)
@@ -76,18 +75,18 @@
 ;; with kill(all) and kill(post_eval_functions)
   (funcall 
    #'(lambda (z)
-       (cond ((and allbutl (memq x allbutl)))
+       (cond ((and allbutl (member x allbutl :test #'eq)))
 	     ((eq (setq x (getopr x)) '$labels)
 	      (dolist (u (cdr $labels))
-		(cond ((and allbutl (memq u allbutl))
+		(cond ((and allbutl (member u allbutl :test #'eq))
 		       (setq z (nconc z (ncons u))))
 		      (t (makunbound u) (remprop u 'time)
 			 (remprop u 'nodisp))))
 	      (setq $labels (cons '(mlist simp) z) $linenum 0 dcount 0))
-	     ((memq x '($values $arrays $aliases $rules $props
-			$let_rule_packages))
+	     ((member x '($values $arrays $aliases $rules $props
+			$let_rule_packages) :test #'eq)
 	      (mapc #'kill1 (cdr (symbol-value x))))
-	     ((memq x '($functions $macros $gradefs $dependencies))
+	     ((member x '($functions $macros $gradefs $dependencies) :test #'eq)
 	      (mapc #'(lambda (y) (kill1 (caar y))) (cdr (symbol-value x))))
 	     ((eq x '$myoptions))
 	     ((eq x '$tellrats) (setq tellratlist nil))
@@ -96,7 +95,7 @@
 	     ((eq x '$features)
 	      (cond ((not (equal (cdr $features) featurel))
 		     (setq $features (cons '(mlist simp) 
-					   (copy-top-level featurel ))))))
+					   (copy-list featurel ))))))
 	     ((eq x '$pre_eval_functions) (setq $pre_eval_functions '((mlist)) ))
 	     ((eq x '$post_eval_functions) (setq $post_eval_functions '((mlist)) ))
 	     ((or (eq x t) (eq x '$all))
@@ -109,8 +108,8 @@
 		    '((mlist simp))
 		    tellratlist nil $dontfactor '((mlist)) $setcheck nil)
 	      (killallcontexts))
-	     ((setq z (assq x '(($inlabels . $inchar) ($outlabels . $outchar)
-				($linelabels . $linechar))))
+	     ((setq z (assoc x '(($inlabels . $inchar) ($outlabels . $outchar)
+				($linelabels . $linechar)) :test #'eq))
 	      (mapc #'(lambda (y) (remvalue y '$kill))
 		    (getlabels* (eval (cdr z)) nil)))
 	     ((and (eq (ml-typep x) 'fixnum) (not (< x 0))) (remlabels x))
@@ -218,18 +217,16 @@
 
 (defmfun nformat (form)
   (cond ((atom form)
-	 (cond ((and (numberp form) (minusp form)) (list '(mminus) (minus form)))
+	 (cond ((and (numberp form) (minusp form)) (list '(mminus) (- form)))
 	       ((eq t form) (if in-p t '$true))
 	       ((eq nil form) (if in-p nil '$false))
-	       ((and displayp (car (assqr form aliaslist))))
-	       ;;	       (($EXTENDP FORM)
-	       ;;		(NFORMAT (transform-extends form)))
+	       ((and displayp (car (rassoc form aliaslist :test #'eq))))
 	       (t form)))
 	((atom (car form))
 	 form)
 	((eq 'rat (caar form))
 	 (cond ((minusp (cadr form))
-		(list '(mminus) (list '(rat) (minus (cadr form)) (caddr form))))
+		(list '(mminus) (list '(rat) (- (cadr form)) (caddr form))))
 	       (t (cons '(rat) (cdr form)))))
 	((eq 'mmacroexpanded (caar form)) (nformat (caddr form)))
 	((null (cdar form)) form)
@@ -240,6 +237,6 @@
 	((eq 'mpois (caar form)) (nformat ($outofpois form)))
 	((eq 'bigfloat (caar form))
 	 (if (minusp (cadr form))
-	     (list '(mminus) (list (car form) (minus (cadr form)) (caddr form)))
+	     (list '(mminus) (list (car form) (- (cadr form)) (caddr form)))
 	     (cons (car form) (cdr form))))
 	(t form)))
