@@ -200,11 +200,20 @@ Maxima code for evaluating orthogonal polynomials listed in Chapter 22 of Abramo
 		    (setq cf (div (mul cf (add i a) x) (mul (add i b) (+ 1 i))))
 		    (setq sum (add cf sum)))))))
 	(t
-	 `((%sum )
-	   ((mtimes) ((mexpt) ((mfactorial) ,$genindex) -1)
-	    (($pochhammer) ,a ,$genindex)
-	    ((mexpt) (($pochhammer ) ,b ,$genindex) -1) 
-	    ((mexpt) ,x ,$genindex)) ,$genindex 0 ,n))))
+; The following is replaced with simplifying code.
+;	 `((%sum )
+;	   ((mtimes) ((mexpt) ((mfactorial) ,$genindex) -1)
+;	    (($pochhammer) ,a ,$genindex)
+;	    ((mexpt) (($pochhammer ) ,b ,$genindex) -1) 
+;	    ((mexpt) ,x ,$genindex)) ,$genindex 0 ,n))))
+         (let ((index (gensumindex)))
+           (simplify
+             (list '(%sum)
+                   (mul (inv (take '(mfactorial) index))
+                        (take '($pochhammer) a index)
+                        (inv (take '($pochhammer) b index))
+                        (power x index))
+                   index 0 n))))))
 
 ;; return the F[2,1] hypergeometic sum from 0 to n. Use genindex as the 
 ;; sum index; genindex is defined in asum.lisp
@@ -228,13 +237,22 @@ Maxima code for evaluating orthogonal polynomials listed in Chapter 22 of Abramo
 		    (setq sum (add cf sum)))))))
 	
 	(t
-	 `((%sum)
-	   ((mtimes) (($pochhammer) ,a ,$genindex) (($pochhammer) ,b ,$genindex)
-	    ((mexpt) (($pochhammer) ,c ,$genindex) -1)
-	    ((mexpt) ((mfactorial) ,$genindex) -1)
-	    ((mexpt) ,x ,$genindex)) 
-	   ,$genindex 0 ,n))))
-   
+; The following is replaced with simplifying code.
+;	 `((%sum)
+;	   ((mtimes) (($pochhammer) ,a ,$genindex) (($pochhammer) ,b ,$genindex)
+;	    ((mexpt) (($pochhammer) ,c ,$genindex) -1)
+;	    ((mexpt) ((mfactorial) ,$genindex) -1)
+;	    ((mexpt) ,x ,$genindex)) 
+;	   ,$genindex 0 ,n))))
+	 (let ((index (gensumindex)))
+           (simplify
+             (list '(%sum)
+                   (mul (take '($pochhammer) a index)
+                        (take '($pochhammer) b index)
+                        (inv (take '($pochhammer) c index))
+                        (inv (take '(mfactorial) index))
+                        (power x index))
+                   index 0 n))))))
 
 (eval-when
     #+gcl (load eval)
@@ -713,7 +731,10 @@ Maxima code for evaluating orthogonal polynomials listed in Chapter 22 of Abramo
 		  (setq d 1))
 		 ((< m 0)
 		  (setq f ($assoc_legendre_p n (neg m) x))
-		  (setq d (div (factorial (+ n m)) (factorial (- n m))))
+		  ;; Adding a factor (-1)^m to the transformation to get the
+		  ;; expected results for odd negative integers. DK 09/2009
+		  (setq d (mul (power -1 m)
+		               (div (factorial (+ n m)) (factorial (- n m)))))
 		  (setq dx 1))
 		 (t
 		  (cond ((eq m 0)
@@ -1099,7 +1120,7 @@ Maxima code for evaluating orthogonal polynomials listed in Chapter 22 of Abramo
 			       ($spherical_harmonic n (- m) th (mul -1 p))))
 	       (t
 		(interval-mult
-		 (mul (simplify ($exp (mul '$%i m p)))
+		 (mul ($exp (mul '$%i m p))
 		      (power (div (* (+ (* 2 n) 1) (factorial (- n m)))
 				  (mul '$%pi (* 4 (factorial (+ n m))))) 
 			     `((rat) 1 2)))
