@@ -259,7 +259,15 @@
                  (inv arg) 
                  (take '(%bessel_j) (- order 1) arg))
             (take '(%bessel_j) (- order 2) arg)))
-      
+
+      ((and $%iargs (multiplep arg '$%i))
+       ;; bessel_j(v, %i*x) = (%i*x)^v/(x^v) * bessel_i(v, x)
+       ;; (From http://functions.wolfram.com/03.01.27.0002.01)
+       (let ((x (coeff arg '$%i 1)))
+	 (mul (power (mul '$%i x) order)
+	      (inv (power x order))
+	      (take '(%bessel_i) order x))))
+
       ($hypergeometric_representation
         ;; Return Hypergeometric representation of bessel_j
         (mul (inv (take '(%gamma) (add order 1)))
@@ -311,7 +319,7 @@
           ;; We have a real arg and order > 0 and order not 0 or 1
           ;; for this case we can call the function dbesj
           (multiple-value-bind (n alpha) (floor (float order))
-            (let ((jvals (make-array (1+ n) :element-type 'double-float)))
+            (let ((jvals (make-array (1+ n) :element-type 'flonum)))
               (slatec:dbesj (abs (float arg)) alpha (1+ n) jvals 0)
               (cond ((>= arg 0) 
                      (aref jvals n))
@@ -347,8 +355,8 @@
             (* 0.5 (+ (hankel-1 order arg) (hankel-2 order arg))))
            (t
             (multiple-value-bind (n alpha) (floor (float order))
-              (let ((cyr (make-array (1+ n) :element-type 'double-float))
-                    (cyi (make-array (1+ n) :element-type 'double-float)))
+              (let ((cyr (make-array (1+ n) :element-type 'flonum))
+                    (cyi (make-array (1+ n) :element-type 'flonum)))
                 (multiple-value-bind (v-zr v-zi v-fnu v-kode v-n
                                            v-cyr v-cyi v-nz v-ierr)
                    (slatec:zbesj (float (realpart arg))
@@ -417,7 +425,7 @@
     (cond
      (($oddp n)
       ;; integrate(bessel_y(2*N+1,z)) , N > 0 
-      ;; = -bessel_y(0,z) - 2 * sum(bessel_y(2*k,z),k,1,(n-1)/2)
+      ;; = -bessel_y(0,z) - 2 * sum(bessel_y(2*k,z),k,1,N)
       (let* ((k (gensym))
 	     (answer `((mplus) ((mtimes) -1 ((%bessel_y) 0 z))
                        ((mtimes) -2
@@ -431,19 +439,23 @@
       ;; integrate(bessel_y(2*N,z)) , N > 0
       ;; = (1/2)*%pi*z*(bessel_y(0,z)*struve_h(-1,z)
       ;;               +bessel_y(1,z)*struve_h(0,z))
-      ;;    - 2 * sum(bessel_y(2*k,z),k,1,n/2)
+      ;;    - 2 * sum(bessel_y(2*k+1,z),k,0,N-1)
       (let* 
 	  ((k (gensym))
 	   (answer `((mplus)
 		     ((mtimes) -2
-		      ((%sum) ((%bessel_y) ((mtimes) 2 ,k) z) ,k 1
-		       ((mtimes) ((rat) 1 2) ,n)))
+		      ((%sum)
+		       ((%bessel_y) ((mplus) 1 ((mtimes) 2 ,k)) z)
+		       ,k 0
+		       ((mplus)
+		        -1
+		        ((mtimes) ((rat) 1 2) ,n))))
 		     ((mtimes) ((rat) 1 2) $%pi z
 		      ((mplus)
-		       ((mtimes) 
+		       ((mtimes)
 			((%bessel_y) 0 z)
 			((%struve_h) -1 z))
-		       ((mtimes) 
+		       ((mtimes)
 			((%bessel_y) 1 z)
 			((%struve_h) 0 z)))))))
 	;; Expand out the sum if n < 10.  Otherwise fix up the indices
@@ -522,7 +534,7 @@
                     ($float t)
                     (order ($float order))
                     (arg ($float arg))
-                    (dpi (coerce pi 'double-float)))
+                    (dpi (coerce pi 'flonum)))
                 ($float
                   ($rectform
                     (add
@@ -661,7 +673,7 @@
                          (t result))))))
          (t
           (multiple-value-bind (n alpha) (floor (float order))
-            (let ((jvals (make-array (1+ n) :element-type 'double-float)))
+            (let ((jvals (make-array (1+ n) :element-type 'flonum)))
               ;; First we do the calculation for an positive argument.
               (slatec:dbesy (abs (float arg)) alpha (1+ n) jvals)
               
@@ -669,7 +681,7 @@
               (cond ((>= arg 0)                
                      (aref jvals n))
                     (t
-                     (let* ((dpi (coerce pi 'double-float))
+                     (let* ((dpi (coerce pi 'flonum))
                             (s1 (cis (- (* order dpi))))
                             (s2 (* #c(0 2) (cos (* order dpi)))))
                        (let ((result (+ (* s1 (aref jvals n)) 
@@ -696,10 +708,10 @@
                (complex 0 2)))
            (t
             (multiple-value-bind (n alpha) (floor (float order))
-              (let ((cyr (make-array (1+ n) :element-type 'double-float))
-                    (cyi (make-array (1+ n) :element-type 'double-float))
-                    (cwrkr (make-array (1+ n) :element-type 'double-float))
-                    (cwrki (make-array (1+ n) :element-type 'double-float)))
+              (let ((cyr (make-array (1+ n) :element-type 'flonum))
+                    (cyi (make-array (1+ n) :element-type 'flonum))
+                    (cwrkr (make-array (1+ n) :element-type 'flonum))
+                    (cwrki (make-array (1+ n) :element-type 'flonum)))
                 (multiple-value-bind (v-zr v-zi v-fnu v-kode v-n v-cyr v-cyi 
                                            v-nz v-cwrkr v-cwrki v-ierr)
                    (slatec::zbesy (float (realpart arg))
@@ -765,22 +777,22 @@
 (defun bessel-i-integral-2 (n unused)
   (declare (ignore unused))
   (case n
-	(0 
+	(0
 	 ;; integrate(bessel_i(0,z)
 	 ;; = (1/2)*z*(bessel_i(0,z)*(%pi*struve_l(1,z)+2)
 	 ;;            -%pi*bessel_i(1,z)*struve_l(0,z))
 	 '((mtimes) ((rat) 1 2) z
 	   ((mplus)
-	    ((mtimes) -1 $%pi 
+	    ((mtimes) -1 $%pi
 	     ((%bessel_i) 1 z)
 	     ((%struve_l) 0 z))
-	    ((mtimes) 
+	    ((mtimes)
 	     ((%bessel_i) 0 z)
 	     ((mplus) 2
 	      ((mtimes) $%pi ((%struve_l) 1 z)))))))
 	(1
-	 ;; integrate(bessel_j(1,z) = -bessel_i(0,z)
-	 '((mtimes) -1 ((%bessel_i) 0 z)))
+	 ;; integrate(bessel_i(1,z) = bessel_i(0,z)
+	 '((%bessel_i) 0 z))
 	(otherwise nil)))
 
 (putprop '%bessel_i `((n z) nil ,#'bessel-i-integral-2) 'integral)
@@ -905,7 +917,14 @@
                  (inv arg) 
                  (take '(%bessel_i) (- order 1) arg))
             (take '(%bessel_i) (- order 2) arg)))
-      
+
+      ((and $%iargs (multiplep arg '$%i))
+       ;; bessel_i(v, %i*x) = (%i*x)^v/(x^v) * bessel_j(v, x)
+       ;; (From http://functions.wolfram.com/03.02.27.0002.01)
+       (let ((x (coeff arg '$%i 1)))
+	 (mul (power (mul '$%i x) order)
+	      (inv (power x order))
+	      (take '(%bessel_j) order x))))
       ($hypergeometric_representation
         ;; Return Hypergeometric representation of bessel_i
         (mul (inv (take '(%gamma) (add order 1)))
@@ -967,9 +986,31 @@
          (t
           ;; Now the case order > 0 and arg >= 0
           (multiple-value-bind (n alpha) (floor (float order))
-            (let ((jvals (make-array (1+ n) :element-type 'double-float)))
+            (let ((jvals (make-array (1+ n) :element-type 'flonum)))
               (slatec:dbesi (float (realpart arg)) alpha 1 (1+ n) jvals 0)
               (aref jvals n)))))))
+
+    ((and (zerop (realpart arg))
+	  (zerop (rem order 1)))
+     ;; Handle the case for a pure imaginary arg and integer order.
+     ;; In this case, the result is purely real or purely imaginary,
+     ;; so we want to make sure that happens.
+     ;;
+     ;; bessel_i(n, %i*x) = (%i*x)^n/x^n * bessel_j(n,x)
+     ;;    = %i*n * bessel_j(n,x)
+     (let* ((n (floor order))
+	    (result (bessel-j (float n) (imagpart arg))))
+       (cond ((evenp n)
+	      ;; %i^(2*m) = (-1)^m, where n=2*m
+	      (if (evenp (/ n 2))
+		  result
+		  (- result)))
+	     ((oddp n)
+	      ;; %i^(2*m+1) = %i*(-1)^m, where n = 2*m+1
+	      (if (evenp (floor n 2))
+		  (complex 0 result)
+		  (complex 0 (- result)))))))
+
     (t
      ;; The arg is complex.  Use the complex-valued Bessel function.
      (multiple-value-bind (n alpha) (floor (abs (float order)))
@@ -991,7 +1032,7 @@
            (cond ((minusp order)
                   ;;  I(-a,z) = I(a,z) + (2/pi)*sin(pi*a)*K(a,z)
                   (+ (complex (aref cyr n) (aref cyi n))
-                     (let ((dpi (coerce pi 'double-float)))
+                     (let ((dpi (coerce pi 'flonum)))
                        (* (/ 2.0 dpi)
                           (sin (* dpi (- order))) 
                           (bessel-k (- order) arg)))))
@@ -1082,16 +1123,21 @@
 		     ((mtimes) 2
 		      ((%sum)
 		       ((mtimes)
-			((%bessel_y) ((mplus) 1 ((mtimes) 2 ,k)) z)
+			((%bessel_k) ((mplus) 1 ((mtimes) 2 ,k)) z)
 			((mexpt) -1
 			 ((mplus) ,k ((mtimes) ((rat) 1 2) ,n))))
 		       ,k 0 ((mplus) -1 ((mtimes) ((rat) 1 2) ,n))))
-		     ((mtimes) ((rat) 1 2) $%pi
-		      ((mexpt) -1 ((mtimes) ((rat) 1 2) ,n)) z
+	             ((mtimes)
+	              ((rat) 1 2)
+	              $%pi
+	              ((mexpt) -1 ((mtimes) ((rat) 1 2) ,n))
+	              z
 		      ((mplus)
-		       ((mtimes) ((%bessel_k) 0 z)
+		       ((mtimes)
+		        ((%bessel_k) 0 z)
 			((%struve_l) -1 z))
-		       ((mtimes) ((%bessel_k) 1 z)
+		       ((mtimes)
+		        ((%bessel_k) 1 z)
 			((%struve_l) 0 z)))))))
 	;; expand out the sum if n < 10.  Otherwise fix up the indices
 	(if (< n 10) 
@@ -1144,6 +1190,7 @@
 
 (defun simp-bessel-k (expr ignored z)
   (declare (ignore ignored))
+  (twoargcheck expr)
   (let ((order (simpcheck (cadr expr) z))
         (arg (simpcheck (caddr expr) z))
         (rat-order nil))
@@ -1244,7 +1291,7 @@
           ;; This is the extension for negative arg.
           ;; We use the following formula for evaluation:
           ;; K[v](-z) = exp(-i*pi*v) * K[n][z]-i * pi *I[n](z)
-          (let* ((dpi (coerce pi 'double-float))
+          (let* ((dpi (coerce pi 'flonum))
                  (s1 (cis (* dpi (- (abs order)))))
                  (s2 (* (complex 0 -1) dpi))
                  (result (+ (* s1 (bessel-k (abs order) (- arg)))
@@ -1268,7 +1315,7 @@
           ;; From A&S 9.6.6, K(-v,z) = K(v,z), so take the
           ;; absolute value of the order.
           (multiple-value-bind (n alpha) (floor (abs (float order)))
-            (let ((jvals (make-array (1+ n) :element-type 'double-float)))
+            (let ((jvals (make-array (1+ n) :element-type 'flonum)))
               (slatec:dbesk (float arg) alpha 1 (1+ n) jvals 0)
               (aref jvals n)))))))
     (t
@@ -1504,7 +1551,7 @@
          ((or ($oddp  order)
               ($featurep order '$odd)) 
           ;; order is an odd integer, pure imaginary noun-form
-          (cons 0 expr))
+          (cons 0 (mul -1 '$%i expr)))
          ((or ($evenp order)
               ($featurep order '$even))
            ;; order is an even integer, real noun-form
@@ -1525,7 +1572,7 @@
        (cond
           ((eq sign-arg '$neg)
            ;; order is half integral and arg negative, imaginary noun-form
-           (cons 0 expr))
+           (cons 0 (mul -1 '$%i expr)))
           (t
             ;; the sign of arg or order is not known
             (risplit-noun expr))))
@@ -1571,7 +1618,7 @@
        ;; order is half integral
        (cond
           ((eq sign-arg '$neg)
-           (cons 0 expr))
+           (cons 0 (mul -1 '$%i expr)))
           (t
             ;; the sign of arg is not known
             (risplit-noun expr))))
@@ -1652,6 +1699,7 @@
 
 (defun simp-hankel-1 (expr ignored z)
   (declare (ignore ignored))
+  (twoargcheck expr)
   (let ((order (simpcheck (cadr expr) z))
 	(arg   (simpcheck (caddr expr) z))
         rat-order)
@@ -1738,6 +1786,7 @@
 
 (defun simp-hankel-2 (expr ignored z)
   (declare (ignore ignored))
+  (twoargcheck expr)
   (let ((order (simpcheck (cadr expr) z))
 	(arg   (simpcheck (caddr expr) z))
         rat-order)
@@ -1831,6 +1880,7 @@
 
 (defun simp-struve-h (expr ignored z)
   (declare (ignore ignored))
+  (twoargcheck expr)
   (let ((order (simpcheck (cadr expr) z))
         (arg   (simpcheck (caddr expr) z)))
     (cond
@@ -2075,6 +2125,7 @@
 
 (defun simp-struve-l (expr ignored z)
   (declare (ignore ignored))
+  (twoargcheck expr)
   (let ((order (simpcheck (cadr expr) z))
         (arg   (simpcheck (caddr expr) z)))
     (cond
