@@ -70,6 +70,60 @@
 	 `(member ,(intern (string item) (find-package 'keyword)) *features*))
 	((equal option 'gctime) 0)))
 
+#+(or scl allegro)
+(defun string<$ (str1 str2)
+  "Compare string, but flip the case for maxima variable names to maintain
+  the same order irrespective of the lisp case mode."
+  (declare (string str1 str2))
+  (cond (#+scl (eq ext:*case-mode* :lower)
+	 #+allegro (eq excl:*current-case-mode* :case-sensitive-lower)
+	 (let ((str1l (length str1))
+	       (str2l (length str2)))
+	   (cond ((and (> str1l 1) (char= (aref str1 0) #\$)
+		       (> str2l 1) (char= (aref str2 0) #\$))
+		  (flet ((case-flip (str)
+			   (let ((some-upper nil)
+				 (some-lower nil))
+			     (dotimes (i (length str))
+			       (let ((ch (schar str i)))
+				 (when (lower-case-p ch)
+				   (setf some-lower t))
+				 (when (upper-case-p ch)
+				   (setf some-upper t))))
+			     (cond ((and some-upper some-lower)
+				    nil)
+				   (some-upper
+				    :downcase)
+				   (some-lower
+				    :upcase)))))
+		    (let ((flip1 (case-flip str1))
+			  (flip2 (case-flip str2)))
+		      (do ((index 1 (1+ index)))
+			  ((or (>= index str1l) (>= index str2l))
+			   (if (= index str1l) index nil))
+			(let ((ch1 (aref str1 index))
+			      (ch2 (aref str2 index)))
+			  (cond ((and (eq flip1 :downcase) (both-case-p ch1))
+				 (setf ch1 (char-downcase ch1)))
+				((and (eq flip1 :upcase) (both-case-p ch1))
+				 (setf ch1 (char-upcase ch1))))
+			  (cond ((and (eq flip2 :downcase) (both-case-p ch2))
+				 (setf ch2 (char-downcase ch2)))
+				((and (eq flip2 :upcase) (both-case-p ch2))
+				 (setf ch2 (char-upcase ch2))))
+			  (unless (char= ch1 ch2)
+			    (return (if (char< ch1 ch2)
+					index
+					nil))))))))
+		 (t
+		  (string< str1 str2)))))
+	(t
+	 (string< str1 str2))))
+;;;
+#-(or scl allegro)
+(defun string<$ (str1 str2)
+  (string< str1 str2))
+
 ;;numbers<strings<symbols<lists<?
 (defun alphalessp (x y)
   (cond ((numberp x)
@@ -85,7 +139,7 @@
 		(let ((nx (symbol-name x))
 		      (ny (symbol-name y)))
 		  (declare (string nx ny))
-		  (cond ((string< nx ny)
+		  (cond ((string<$ nx ny)
 			 t)
 			((string= nx ny)
 			 (cond ((eq nx ny) nil)
@@ -334,7 +388,7 @@
 (setf ext::*intexp-maximum-exponent* 100000)
 ;;;; Setup the mapping from the Maxima 'flonum float type to a CL float type.
 ;;;;
-;;;; Add :flonum-log to *features* if you want flonum to be a
+;;;; Add :flonum-long to *features* if you want flonum to be a
 ;;;; long-float.  Or add :flonum-double-double if you want flonum to
 ;;;; be a double-double (currently only for CMUCL).  Otherwise, you
 ;;;; get double-float as the flonum type.
@@ -377,7 +431,7 @@
 #+flonum-long
 (progn
 ;;;; The Maxima 'flonum can be a CL 'long-float on the Scieneer CL or CLISP,
-;;;; but should be the same a 'double-float on other CL implementations.
+;;;; but should be the same as 'double-float on other CL implementations.
 
   (eval-when (:compile-toplevel :load-toplevel :execute)
     (setq *read-default-float-format* 'long-float))
