@@ -321,11 +321,6 @@
        (merror
          (intl:gettext
            "depends: argument must be a non-atomic expression; found ~M") z))
-      ((or (eq (caar z) 'mqapply)
-           (member 'array (cdar z) :test #'eq))
-       (merror
-         (intl:gettext
-           "depends: argument cannot be a subscripted expression; found ~M") z))
       (t
        (do ((zz z (cdr zz))
             (y nil))
@@ -335,7 +330,10 @@
             (unless (cdr $dependencies)
               (setq $dependencies (copy-list '((mlist simp)))))
             (add2lnc (cons (cons (caar z) nil) y) $dependencies))
-         (cond ((not (symbolp (cadr zz)))
+         (cond ((and ($subvarp (cadr zz))
+                     (not (member (caar (cadr zz)) y)))
+                (setq y (push (cadr zz) y)))
+               ((not (symbolp (cadr zz)))
                 (merror
                   (intl:gettext "depends: argument must be a symbol; found ~M")
                   (cadr zz)))
@@ -755,7 +753,9 @@
 	(setq ans (list '(mequal simp) (disp2 l) ans)))
     (if lablist (nconc lablist (cons (elabel ans) nil)))
     (setq tim (get-internal-run-time))
-    (displa (list '(mlable) (if lablist linelable) ans))
+    (let ((*display-labels-p* nil))
+      (declare (special *display-labels-p*))
+      (displa (list '(mlable) (if lablist linelable) ans)))
     (mterpri)
     (timeorg tim)))
 
@@ -1164,6 +1164,24 @@
 
 (defmfun $fix (e) (take '($floor) e))
 
+;; Evaluate THUNK ignoring any error that might occur.  If the THUNK
+;; returns a good number (not infinity or NaN), then return the
+;; number.  Otherwise, return NIL to indicate that we the computation
+;; failed.  This is a pretty brute-force approach.
+(defun try-float-computation (thunk)
+  (let ((errcatch (cons bindlist loclist))
+	(*mdebug* nil))
+    (let ((result (errset (funcall thunk))))
+      (labels ((bad-number-p (num)
+		 (if (complexp num)
+		     (or (bad-number-p (realpart num))
+			 (bad-number-p (imagpart num)))
+		     (or (float-inf-p num)
+			 (float-nan-p num)))))
+	(if (and result (bad-number-p (car result)))
+	    nil
+	    (car result))))))
+	    
 (defmfun $float (e)
   (cond ((numberp e) (float e))
 	((and (symbolp e) (mget e '$numer)))
@@ -1188,19 +1206,20 @@
 		  ;; float(log(int)).  First try to compute (log
 		  ;; (float n)).  If that works, we're done.
 		  ;; Otherwise we need to do more.  
-		  (to (or #-(or gcl ecl) (ignore-errors (log (float n)))
+		  (to (or (try-float-computation #'(lambda ()
+						     (log (float n))))
 			  (let ((m (integer-length n)))
 			    ;; Write n as (n/2^m)*2^m where m is the number of
 			    ;; bits in n.  Then log(n) = log(2^m) + log(n/2^m).
 			    ;; n/2^m is approximately 1, so converting that to a
 			    ;; float is no problem.  log(2^m) = m * log(2).
-			    (+ (* m (log 2d0))
+			    (+ (* m (log 2e0))
 			       (log (float (/ n (ash 1 m)))))))))
 		 (($ratnump n)
 		  ;; float(log(n/m)) where n and m are integers.  Try computing
 		  ;; it first.  If it fails, compute as log(n) - log(m).
-		  (let ((try #-(or gcl ecl)
-			     (ignore-errors (log (fpcofrat n)))))
+		  (let ((try (try-float-computation #'(lambda() 
+							(log (fpcofrat n))))))
 		    (if try
 			(to try)
 			(sub  ($float `((%log) ,(second n)))
@@ -1209,13 +1228,13 @@
 		  ;; float(log(n+m*%i)).
 		  (let ((re ($realpart n))
 			(im ($imagpart n)))
-		    (to (or #-(or gcl ecl)
-			    (ignore-errors (log (complex (float re)
-							 (float im))))
+		    (to (or (try-float-computation #'(lambda ()
+						       (log (complex (float re)
+								     (float im)))))
 			    (let* ((size (max (integer-length re)
 					      (integer-length im)))
 				   (scale (ash 1 size)))
-			      (+ (* size (log 2d0))
+			      (+ (* size (log 2e0))
 				 (log (complex (float (/ re scale))
 					       (float (/ im scale))))))))))
 		 (t
