@@ -444,6 +444,9 @@
 
 (declare-top (special $numer $logarc $trigsign))
 
+;; atan2 distributes over lists, matrices, and equations
+(defprop $atan2 (mlist $matrix mequal) distribute_over)
+
 (defun simpatan2 (expr vestigial z)     ; atan2(y,x) ~ atan(y/x)
   (declare (ignore vestigial))
   (twoargcheck expr)
@@ -751,7 +754,10 @@
   (prog (arra ary)
      (setq arra val)
      (setq ary sym)
-     (if (and arra (or (hash-table-p arra) (arrayp arra)))
+     (if (and arra
+              (or (hash-table-p arra)
+                  (arrayp arra)
+                  (eq (marray-type arra) '$functional)))
 	 (cond ((hash-table-p arra)
 		(let ((dim1 (gethash 'dim1 arra)))
 		  (return (list* '(mlist) '$hash_table (if dim1 1 t)
@@ -765,8 +771,10 @@
 		(return (let ((dims (array-dimensions arra)))
 			  (list '(mlist) '$declared
 				;; they don't want more info (array-type arra)
-				(length dims)
-				(cons '(mlist) (mapcar #'1- dims)))))))
+			        (length dims)
+			        (cons '(mlist) (mapcar #'1- dims))))))
+	       ((eq (marray-type arra) '$functional)
+	        (return (arrayinfo-aux sym (mgenarray-content arra)))))
 	 (let ((gen (mgetl sym '(hashar array))) ary1)
            (when (null gen)
              (merror (intl:gettext "arrayinfo: ~M is not an array.") ary))
@@ -791,7 +799,6 @@
 				  (length (cdr ary1))
 				  (cons '(mlist simp) (mapcar #'1- (cdr ary1)))))))))))
 
-
 ;;;; ALIAS
 
 (declare-top (special aliaslist aliascntr greatorder lessorder))
