@@ -59,13 +59,6 @@
 
 (defmvar displayp nil "Is T when inside of `displa'")
 
-;; More messages which appear during the middle of display.  Different
-;; from those which appear during typein.  MOREMSG and MOREFLUSH get
-;; bound to these.
-
-(defvar d-moremsg "--More Display?--")
-(defvar d-moreflush "--Display Flushed--")
-
 ;; Parameters which control how boxes, absolute value signs,
 ;; evaluation-at-a-point bars, and matrices are drawn.
 
@@ -104,10 +97,7 @@
 	       (height    0) (depth   0) (level   0) (size   2)
 	       (break     0) (right   0) (lines   1) bkpt
 	       (bkptwd    0) (bkptht  1) (bkptdp  0) (bkptout 0)
-	       (bkptlevel 0) in-p
-	       (moreflush d-moreflush)
-	       more-^w
-	       (moremsg d-moremsg))
+	       (bkptlevel 0) in-p)
 	   (setq dim-list (dimension form nil 'mparen 'mparen 0 0))
 	   (cond ($cursordisp  (draw-2d (nreverse dim-list) at-x at-y))
 		 (t
@@ -133,10 +123,7 @@
 			  (height    0) (depth   0) (level   0) (size   2)
 			  (break     0) (right   0) (lines   1) bkpt
 			  (bkptwd    0) (bkptht  1) (bkptdp  0) (bkptout 0)
-			  (bkptlevel 0) in-p
-			  (moreflush d-moreflush)
-			  more-^w
-			  (moremsg d-moremsg))
+			  (bkptlevel 0) in-p)
 		      (unwind-protect
 			   (progn
 			     (setq form (dimension form nil 'mparen 'mparen 0 0))
@@ -768,9 +755,7 @@
      (update-heights height depth)
      (return result)))
 
-(displa-def mminus dimension-prefix "- ")
 (displa-def mplus  dim-mplus)
-
 (defprop munaryplus (#\+ #\space) dissym)
 
 (defun dim-mplus (form result)
@@ -807,6 +792,52 @@
 			    d (max d depth))
 		      (checkbreak result w)))))))
 
+(displa-def mminus dim-mminus)
+(defprop munaryminus (#\- #\space) dissym)
+(def-rbp munaryminus 134)
+(def-rbp munaryminus 100)
+
+(defun dim-mminus (form result)
+  (cond ((and (null (cddr form))
+              (not (member (cadar form) '(trunc exact) :test #'eq)))
+         (if (null (cdr form))
+             (dimension-function form result)
+             (dimension-prefix (cons '(munaryminus) (cdr form)) result)))
+        (t
+         (setq result (dimension (cadr form) result lop 'mminus 0 0))
+         (checkbreak result width)
+         (do ((l (cddr form) (cdr l))
+              (w width)
+              (h height)
+              (d depth)
+              (trunc (member 'trunc (cdar form) :test #'eq))
+              (dissym))
+             ((null l)
+              (cond (trunc
+                     (setq width (+ 8 w)
+                           height h
+                           depth d)
+                     (push-string " + . . ." result)))
+              result)
+           (if (mmminusp (car l))
+               (setq dissym '(#\space #\+ #\space) form (cadar l))
+               (setq dissym '(#\space #\- #\space) form (car l)))
+           (cond ((and (not trunc) (null (cdr l)))
+                  (setq result (dimension form (append dissym result)
+                                          'mminus rop (+ 3 w) right)
+                        width (+ 3 w width)
+                        height (max h height)
+                        depth (max d depth))
+                  (return result))
+                 (t
+                  (setq result
+                        (dimension form (append dissym result)
+                                   'mminus 'mminus (+ 3 w) 0)
+                        w (+ 3 w width)
+                        h (max h height)
+                        d (max d depth))
+                  (checkbreak result w)))))))
+
 (displa-def %sum   dim-%sum 110.)
 (displa-def %limit dim-%limit 110. 110.)
 (displa-def %lsum   dim-%lsum 110.)
@@ -1016,11 +1047,18 @@
 (displa-def $matrix dim-$matrix)
 
 (defun dim-$matrix (form result)
-  (prog (dmstr rstr cstr consp)
+  (prog (dmstr rstr cstr consp cols)
+     (setq cols (if ($listp (cadr form)) (length (cadr form)) 0))
      (if (or (null (cdr form))
-	     (memalike '((mlist simp)) (cdr form))
-	     (dolist (row (cdr form)) (if (not ($listp row)) (return t))))
-	 (return (dimension-function form result)))
+             (memalike '((mlist simp)) (cdr form))
+             ;; Check if the matrix has lists as rows with a equal number of
+             ;; columns.
+             (dolist (row (cdr form))
+               (if (or (not ($listp row))
+                       (not (eql cols (length row))))
+                   (return t))))
+         ;; The matrix is not well formed. Display the matrix in linear mode.
+         (return (dimension-function form result)))
      (do ((l (cdadr form) (cdr l))) ((null l))
        (setq dmstr (cons nil dmstr) cstr (cons 0 cstr)))
      (do ((r (cdr form) (cdr r)) (h1 0) (d1 0))
@@ -1190,7 +1228,6 @@
          ;; MEANING OF FOLLOWING MESSAGE IS OBSCURE.
          (merror (intl:gettext "display: 'checkbreak' not found."))))
 	 (output bkpt 0)
-	 (let ((#.ttyoff (or #.ttyoff more-^w))))
 	 (setq lines (1+ lines)
 	       bkpt result bkptout bkptwd bkptwd w
 	       bkptht maxht bkptdp maxdp bkptlevel level maxht 1 maxdp 0))
@@ -1259,7 +1296,7 @@
   (cond
     ;; If output is turned off to the console and no WRITEFILE is taking
     ;; place, then don't output anything.
-    ((and (or #.ttyoff more-^w) (not #.writefilep)))
+    ((and #.ttyoff (not #.writefilep)))
     ;; If the terminal can't do cursor movement, or we are writing
     ;; to a WRITEFILE (#.writefilep is on) or the terminal is scrolling or
     ;; something else random, then draw equations line by line.
@@ -1285,7 +1322,6 @@
   (do ((i (1- (+ bkptht bkptdp)) (1- i)))
       ((< i 0))
     (cond ((null (aref linearray i)))
-	  (more-^w (output-linear-one-line i))
 	  (t (output-linear-one-line i)))))
 
 (defun output-linear-one-line (i)
