@@ -85,12 +85,12 @@
 	  $setcheckbreak $setval $showtime $signbfloat $simp $simpsum
 	  $solvedecomposes $solveexplicit $solvefactors $solvenullwarn
 	  $solveradcan $solvetrigwarn $sparse
-	  $special $sqrtdispflag $stardisp $sublis_apply_lambda
+	  $sqrtdispflag $stardisp $sublis_apply_lambda
 	  $subnumsimp $sumexpand $sumsplitfact
 	  $superlogcon $suspend $taylor_logexpand
 	  $taylor_truncate_polynomials $timer $timer_devalue
 	  $to_call_lisp_compiler $trace $trace_break_arg $trace_max_indent
-	  $trace_safety $transbind $transcompile $translate $transrun
+	  $trace_safety $transcompile $translate $transrun
 	  $trigexpand $trigexpandplus $trigexpandtimes $triginverses
 	  $trigsign $tr_array_as_ref $tr_bound_function_applyp
 	  $tr_file_tty_messagesp $tr_float_can_branch_complex
@@ -99,7 +99,7 @@
 	  $tr_predicate_brain_damage $tr_semicompile $tr_state_vars
 	  $tr_true_name_of_file_being_translated $tr_warn_bad_function_calls
 	  $tr_warn_fexpr $tr_warn_meval $tr_warn_mode $tr_warn_undeclared
-	  $tr_warn_undefined_variable $tr_windy $ttyintfun $ttyintnum
+	  $tr_warn_undefined_variable $ttyintfun $ttyintnum
 	  $universe $user_mesfile $use_fast_arrays $values $vect_cross
 	  $zerobern %e-val %p%i %pi-val %pi//2 %pi//4 %pi2 *$any-modes*
 	  *alpha *const* *fnewvarsw *gcdl* *in *in-$batchload* *in-compile*
