@@ -1145,8 +1145,10 @@ wrapper for this."
 	((eq x '$dotassoc) (cput 'mnctimes y 'associative))
 	((eq x 'modulus)
 	 (cond ((null y))
-	       ((integerp y)
-	        (if (or (not (primep y)) (member y '(1 0 -1)))
+	       ((and (integerp y) (plusp y))
+	        ;; modulus must be an integer > 0. Give a warning if not
+	        ;; a prime number.
+	        (if (not (primep y))
 	            (mtell (intl:gettext "warning: assigning ~:M, a non-prime, to 'modulus'~&") y)))
 	       (t (mseterr x y))))
 	((eq x '$setcheck)
@@ -2377,7 +2379,7 @@ wrapper for this."
 
 ;; evflag properties
 (mapc #'(lambda (x) (putprop x t 'evflag))
-      '($exponentialize $%emode $demoivre $logexpand $logarc $lognumer
+      '($exponentialize $%emode $demoivre $logexpand $logarc
 	$radexpand $keepfloat $listarith $float $ratsimpexpons $ratmx
 	$simp $simpsum $simpproduct $algebraic $ratalgdenom $factorflag $ratfac
 	$infeval $%enumer $programmode $lognegint $logabs $letrat
