@@ -3,10 +3,15 @@
 ;;;;;;;;Copyright (c) University of Waikato;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;;;;;;;;Hamilton, New Zeland 1992-95 - all rights reserved;;;;;;;;;;;;;;;;
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
+
+
+;;; NOTE: If you change this file, please file a ticket to the f2cl
+;;; project (trac.common-lisp.net/f2cl/wiki) so that the changes can
+;;; be incorporated into the official version.
 (in-package :f2cl-lib)
 
 (defparameter *f2cl-macros-version*
-  "Id: macros.l,v 1.112 2009/01/08 12:57:19 rtoy Exp $")
+  "$Id: macros.l,v fceac530ef0c 2011/11/26 04:02:26 toy $")
 
 (eval-when
     #+gcl (compile load eval)
@@ -64,6 +69,7 @@ is not included")
 
 (defconstant %false% nil)
 (defconstant %true% t)
+
 ;;------------------------------------------------------------------------------
 
 ;;-----------------------------------------------------------------------------
@@ -175,7 +181,7 @@ is not included")
 ;;
 ;; This is done by making a displaced array to VNAME with the
 ;; appropriate offset.
-(defmacro array-slice (vname type indices bounds)
+(defmacro array-slice (vname type indices bounds &optional offset)
   ;; To figure the size of the sliced array, use ARRAY-TOTAL-SIZE
   ;; instead of the f2cl derived/declared BOUNDS, just in case we
   ;; screwed up or in case we changed the size of the array in some
@@ -197,10 +203,16 @@ is not included")
   ;;
   ;; This seems somewhat reasonable, so let's do that for array
   ;; slices.
-  `(make-array (max 0 (- (array-total-size ,vname) ,(col-major-index indices bounds)))
+  `(make-array (max 0 (- (array-total-size ,vname)
+			 (the fixnum
+			   (+ ,(col-major-index indices bounds)
+			      (or ,offset 0)))))
     :element-type ',type
     :displaced-to ,vname
-    :displaced-index-offset (min (array-total-size ,vname) ,(col-major-index indices bounds))))
+    :displaced-index-offset (min (array-total-size ,vname)
+				 (the fixnum
+				   (+ ,(col-major-index indices bounds)
+				      (or ,offset 0))))))
 
 ;; Compute an initializer for make-array given the data in the list
 ;; DATA.  The array has en element type of TYPE and has dimensions of
@@ -254,12 +266,15 @@ is not included")
 	(cond				; all iterations done
 	  ((zerop ,iteration_count) nil)
 	  ;; execute loop, in/de-crement loop vble and decrement cntr
-	  ,(cons 't 
-		 (append 
-		  (append body
-			  `((setq ,loop-var (the integer4 ,(third do_vble_clause))
-			     ,iteration_count (the integer4 (1- ,iteration_count)))))
-		  '((go loop)))))))))
+	  ,(list 't
+		  (append '(tagbody)
+			  (append 
+			   (append body
+				   `(continue
+				     (setq ,loop-var (the integer4 ,(third do_vble_clause))
+					   ,iteration_count (the integer4 (1- ,iteration_count)))))
+			   '((go loop)))))))
+      exit)))
 
 ;;----------------------------------------------------------------------------
 ;; macro for division 
@@ -374,7 +389,22 @@ is not included")
     (double-float
      (truncate (the (double-float #.(float most-negative-fixnum 1d0)
 				  #.(float most-positive-fixnum 1d0))
-		 x)))))
+		    x)))
+    #+clisp
+    (long-float
+     (truncate (the (long-float #.(float most-negative-fixnum 1l0)
+				#.(float most-positive-fixnum 1l0))
+		 x)))
+    ((complex single-float)
+     (the integer4
+       (truncate (the (single-float #.(float (- (ash 1 31)))
+				    #.(float (1- (ash 1 31))))
+		      (realpart x)))))
+    ((complex double-float)
+     (the integer4
+       (truncate (the (double-float #.(float (- (ash 1 31)) 1d0)
+				    #.(float (1- (ash 1 31)) 1d0))
+		      (realpart x)))))))
 
 #+(or cmu scl)
 (defun int (x)
@@ -394,7 +424,29 @@ is not included")
      (the integer4
        (truncate (the (double-float #.(float (- (ash 1 31)) 1d0)
 				    #.(float (1- (ash 1 31)) 1d0))
-		   x))))))
+		   x))))
+    #+scl
+    (long-float
+     (the integer4
+       (truncate (the (long-float #.(float (- (ash 1 31)) 1l0)
+				  #.(float (1- (ash 1 31)) 1l0))
+		   x))))
+    #+(and cmu double-double)
+    (kernel:double-double-float
+     (the integer4
+       (truncate (the (kernel:double-double-float #.(float (- (ash 1 31)) 1w0)
+						  #.(float (1- (ash 1 31)) 1w0))
+		   x))))
+    ((complex single-float)
+     (the integer4
+	  (truncate (the (single-float #.(float (- (ash 1 31)))
+				       #.(float (1- (ash 1 31))))
+			 (realpart x)))))
+    ((complex double-float)
+     (the integer4
+	  (truncate (the (double-float #.(float (- (ash 1 31)) 1d0)
+				       #.(float (1- (ash 1 31)) 1d0))
+			 (realpart x)))))))
 
 
 (defun ifix (x)
@@ -506,7 +558,13 @@ is not included")
 	   (if (> r 0)
 	       (- r 1)
 	       (+ r 1))
-	   r)))))
+	   r)))
+    #+double-double
+    (kernel:double-double-float
+     (locally 
+       (declare (optimize (space 0) (speed 3)))
+       (values (ftruncate (the kernel:double-double-float x)))))
+    ))
     
 
 #-cmu
@@ -520,7 +578,11 @@ is not included")
     (double-float
      (locally 
        (declare (optimize (space 0) (speed 3)))
-       (values (ftruncate (the double-float x)))))))
+       (values (ftruncate (the double-float x)))))
+    (long-float
+     (locally 
+       (declare (optimize (space 0) (speed 3)))
+       (values (ftruncate (the long-float x)))))))
 
 (defun dint (x)
   (aint x))
@@ -778,6 +840,12 @@ is not included")
      (sqrt (the (or (single-float (0f0)) (member 0f0)) x)))
     (double-float
      (sqrt (the (or (double-float (0d0)) (member 0d0)) x)))
+    #+(or scl clisp)
+    (long-float
+     (sqrt (the (or (long-float (0l0)) (member 0l0)) x)))
+    #+(and cmu double-double)
+    (kernel:double-double-float
+     (sqrt (the (or (kernel:double-double-float (0w0)) (member 0w0)) x)))
     (t
      (sqrt x))))
 
@@ -787,6 +855,12 @@ is not included")
      (log (the (or (single-float (0f0)) (member 0f0)) x)))
     (double-float
      (log (the (or (double-float (0d0)) (member 0d0)) x)))
+    #+(or scl clisp)
+    (long-float
+     (log (the (or (long-float (0l0)) (member 0l0)) x)))
+    #+(and cmu double-double)
+    (kernel:double-double-float
+     (log (the (or (kernel:double-double-float (0w0)) (member 0w0)) x)))
     (t
      (log x))))
   
@@ -824,9 +898,21 @@ is not included")
      (log (the (or (single-float (0.0f0)) (member 0f0)) x) 10f0))
     (double-float
      (log (the (or (double-float (0.0d0)) (member 0d0)) x) 10d0))
+    #+(or scl clisp)
+    (long-float
+     (log (the (or (long-float (0.0l0)) (member 0l0)) x) 10l0))
+    #+(and cmu double-double)
+    (kernel:double-double-float
+     (log (the (or (kernel:double-double-float (0.0w0)) (member 0w0)) x) 10w0))
     (t
      (/ (log x)
 	(typecase x
+	  #+(and cmu double-double)
+	  ((complex kernel:double-double-float)
+	   10w0)
+	  #+(or scl clisp)
+	  ((complex long-float)
+	   10l0)
 	  ((complex double-float)
 	   10d0)
 	  ((complex single-float)
@@ -993,7 +1079,7 @@ causing all pending operations to be flushed"
 	   (open file :direction :io :if-exists :supersede
 		 :if-does-not-exist :create))
 	  ((string-equal s "old")
-	   (open file :direction :io :if-does-not-exist nil))
+	   (open file :direction :io :if-does-not-exist nil :if-exists :overwrite))
 	  ((string-equal s "new")
 	   (open file :direction :io :if-exists nil))
 	  (t
@@ -1461,15 +1547,78 @@ causing all pending operations to be flushed"
 (defun stop (&optional arg)
   (when arg
     (format cl::*error-output* "~A~%" arg))
-  (unless *stop-signals-error-p*
+  (when *stop-signals-error-p*
     (cerror "Continue anyway" "STOP reached")))
 
+(defmacro f2cl-copy-seq (dst src dst-type src-type)
+  (flet ((copy-error ()
+	   (error "F2CL cannot copy arrays of element type ~A to ~A~%"
+		  src-type dst-type)))
+    (cond ((subtypep dst-type 'float)
+	   ;; Copy to float array
+	   (cond ((subtypep src-type 'float)
+		  `(replace ,dst ,src))
+		 ((subtypep src-type 'complex)
+		  ;; Copy complex to float by putting each real and
+		  ;; imaginary part into the float array, in order.
+		  (let ((idx (gensym "IDX-"))
+			(el (gensym "EL-")))
+		    `(loop for ,idx of-type fixnum from 0 by 2 below (length ,dst)
+			for ,el of-type ,src-type across ,src
+			do
+			(progn
+			  (setf (aref ,dst ,idx) (realpart ,el))
+			  (setf (aref ,dst (1+ ,idx)) (imagpart ,el))))))
+		 (t
+		  (copy-error))))
+	  ((subtypep dst-type 'complex)
+	   ;; Copy to complex array
+	   (cond ((subtypep src-type 'float)
+		  (let ((idx (gensym "IDX-"))
+			(dst-idx (gensym "DST-IDX-")))
+		    `(loop for ,idx of-type fixnum from 0 by 2 below (length ,src)
+			for ,dst-idx of-type fixnum from 0 below (length ,dst)
+			do
+			(setf (aref ,dst ,dst-idx) (complex (aref ,src ,idx)
+							    (aref ,src (1+ ,idx)))))))
+		 ((subtypep src-type 'complex)
+		  `(replace ,dst ,src))
+		 (t
+		  (copy-error))))
+	  (t
+	   (copy-error)))))
+
+(defmacro make-compatible-seq (type array array-type)
+  (let ((element-type (second type))
+	(array-type (second array-type)))
+    (cond ((subtypep element-type 'float)
+	   (cond ((subtypep array-type 'complex)
+		  `(make-array (* 2 (length ,array)) :element-type ',element-type))
+		 (t
+		  `(make-array (length ,array) :element-type ',element-type))))
+	  ((subtypep element-type 'complex)
+	   (cond ((subtypep array-type 'complex)
+		  `(make-array (length ,array) :element-type ',element-type))
+		 (t
+		  `(make-array (ceiling (length ,array) 2) :element-type ',element-type))))
+	  (t
+	   (error "Don't know how to make an array with element-type ~A~%" element-type)))))
+
+
 ;;;-------------------------------------------------------------------------
 ;;; end of macros.l
 ;;;
-;;; $Id: f2cl-lib.lisp,v 1.22 2010-12-28 00:05:02 rtoy Exp $
-;;; $Log: f2cl-lib.lisp,v $
-;;; Revision 1.22  2010-12-28 00:05:02  rtoy
+;;; $Id: macros.l,v fceac530ef0c 2011/11/26 04:02:26 toy $
+;;; $Log$
+;;; Revision 1.117  2011/02/28 22:21:07  rtoy
+;;; When opening an old file, we should set :if-exists to :overwrite to
+;;; overwrite the file if written too.
+;;;
+;;; Revision 1.116  2011/02/20 20:51:04  rtoy
+;;; Oops.  STOP should signal an error if *STOP-SIGNALS-ERROR-P* is
+;;; non-NIL.
+;;;
+;;; Revision 1.115  2010/12/28 00:06:52  rtoy
 ;;; Assert the type of the arg to fsqrt to be non-negative, excluding
 ;;; negative zero.
 ;;;
