@@ -10,7 +10,11 @@
 (defmacro get-integrand (fun var)
   `(coerce-float-fun ,fun `((mlist) ,,var)))
 
-
+(defun float-or-lose (val)
+  (let ((v ($float val)))
+    (if (numberp v)
+	v
+	(error (intl:gettext "~A is not a real floating-point number") val))))
 
 (defun quad-qag (fun var a b key &key
 		 (epsrel 1e-8)
@@ -26,14 +30,10 @@
 				   z-limit z-lenw last)
 	    (slatec:dqag #'(lambda (x)
 			     (float (funcall f x)))
-			 (let ((v ($float a)))
-			   (if (numberp v) v (throw 'error nil)))
-			 (let ((v ($float b)))
-			   (if (numberp v) v (throw 'error nil)))
-			 (let ((v ($float epsabs)))
-			   (if (numberp v) v (throw 'error nil)))
-			 (let ((v ($float epsrel)))
-			   (if (numberp v) v (throw 'error nil)))
+			 (float-or-lose a)
+			 (float-or-lose b)
+			 (float-or-lose epsabs)
+			 (float-or-lose epsrel)
 			 key
 			 0.0 0.0 0 0
 			 limit lenw 0 iwork work)
@@ -59,19 +59,15 @@
 				   z-limit z-lenw last)
 	    (slatec:dqags #'(lambda (x)
 			      (float (funcall f x)))
-			  (let ((v ($float a)))
-			    (if (numberp v) v (throw 'error nil)))
-			  (let ((v ($float b)))
-			    (if (numberp v) v (throw 'error nil)))
-			  (let ((v ($float epsabs)))
-			    (if (numberp v) v (throw 'error nil)))
-			  (let ((v ($float epsrel)))
-			    (if (numberp v) v (throw 'error nil)))
+			  (float-or-lose a)
+			  (float-or-lose b)
+			  (float-or-lose epsabs)
+			  (float-or-lose epsrel)
 			  0.0 0.0 0 0
 			  limit lenw 0 iwork work)
 	  (declare (ignore junk z-a z-b z-epsabs z-epsrel z-limit z-lenw last))
 	  (list '(mlist) result abserr neval ier))
-      (error (e)
+      (error ()
 	`(($quad_qags) ,fun ,var ,a ,b
 	  ((mequal) $epsrel ,epsrel)
 	  ((mequal) $epsabs ,epsabs)
@@ -111,7 +107,7 @@
 	     (work (make-array lenw :element-type 'flonum))
 	     (iwork (make-array limit :element-type 'f2cl-lib:integer4))
 	     (f (get-integrand fun var))
-	     (infinity (case inf-type
+	     (infinity (ecase inf-type
 			 ((1 $inf)
 			  ;; Interval is [bound, infinity]
 			  1)
@@ -127,13 +123,10 @@
 				       z-limit z-lenw last)
 		(slatec:dqagi #'(lambda (x)
 				  (float (funcall f x)))
-			      (let ((v ($float bound)))
-				(if (numberp v) v (throw 'error nil)))
+			      (float-or-lose bound)
 			      infinity
-			      (let ((v ($float epsabs)))
-				(if (numberp v) v (throw 'error nil)))
-			      (let ((v ($float epsrel)))
-				(if (numberp v) v (throw 'error nil)))
+			      (float-or-lose epsabs)
+			      (float-or-lose epsrel)
 			      0.0 0.0 0 0
 			      limit lenw 0 iwork work)
 	      (declare (ignore junk z-bound z-inf z-epsabs z-epsrel
@@ -159,16 +152,11 @@
 				   z-limit z-lenw last)
 	    (slatec:dqawc #'(lambda (x)
 			      (float (funcall f x)))
-			  (let ((v ($float a)))
-			    (if (numberp v) v (throw 'error nil)))
-			  (let ((v ($float b)))
-			    (if (numberp v) v (throw 'error nil)))
-			  (let ((v ($float c)))
-			    (if (numberp v) v (throw 'error nil)))
-			  (let ((v ($float epsabs)))
-			    (if (numberp v) v (throw 'error nil)))
-			  (let ((v ($float epsrel)))
-			    (if (numberp v) v (throw 'error nil)))
+			  (float-or-lose a)
+			  (float-or-lose b)
+			  (float-or-lose c)
+			  (float-or-lose epsabs)
+			  (float-or-lose epsrel)
 			  0.0 0.0 0 0
 			  limit lenw 0 iwork work)
 	  (declare (ignore junk z-a z-b z-c z-epsabs z-epsrel z-limit z-lenw last))
@@ -199,13 +187,10 @@
 				   z-leniw z-maxp1 z-lenw)
 	    (slatec:dqawf #'(lambda (x)
 			      (float (funcall f x)))
-			  (let ((v ($float a)))
-			    (if (numberp v) v (throw 'error nil)))
-			  (let ((v ($float omega)))
-			    (if (numberp v) v (throw 'error nil)))
+			  (float-or-lose a)
+			  (float-or-lose omega)
 			  integr
-			  (let ((v ($float epsabs)))
-			    (if (numberp v) v (throw 'error nil)))
+			  (float-or-lose epsabs)
 			  0.0 0.0 0 0
 			  limlst 0 leniw maxp1 lenw iwork work)
 	  (declare (ignore junk z-a z-omega z-integr epsabs z-limlst z-lst
@@ -238,17 +223,12 @@
 				   z-leniw z-maxp1 z-lenw z-lst)
 	    (slatec:dqawo #'(lambda (x)
 			      (float (funcall f x)))
-			  (let ((v ($float a)))
-			    (if (numberp v) v (throw 'error nil)))
-			  (let ((v ($float b)))
-			    (if (numberp v) v (throw 'error nil)))
-			  (let ((v ($float omega)))
-			    (if (numberp v) v (throw 'error nil)))
+			  (float-or-lose a)
+			  (float-or-lose b)
+			  (float-or-lose omega)
 			  integr
-			  (let ((v ($float epsabs)))
-			    (if (numberp v) v (throw 'error nil)))
-			  (let ((v ($float epsrel)))
-			    (if (numberp v) v (throw 'error nil)))
+			  (float-or-lose epsabs)
+			  (float-or-lose epsrel)
 			  0.0 0.0 0 0
 			  leniw maxp1 lenw 0 iwork work)
 	  (declare (ignore junk z-a z-b z-omega z-integr z-epsabs z-epsrel
@@ -276,19 +256,13 @@
 				   z-limit z-lenw last)
 	    (slatec:dqaws #'(lambda (x)
 			      (float (funcall f x)))
-			  (let ((v ($float a)))
-			    (if (numberp v) v (throw 'error nil)))
-			  (let ((v ($float b)))
-			    (if (numberp v) v (throw 'error nil)))
-			  (let ((v ($float alfa)))
-			    (if (numberp v) v (throw 'error nil)))
-			  (let ((v ($float beta)))
-			    (if (numberp v) v (throw 'error nil)))
+			  (float-or-lose a)
+			  (float-or-lose b)
+			  (float-or-lose alfa)
+			  (float-or-lose beta)
 			  wfun
-			  (let ((v ($float epsabs)))
-			    (if (numberp v) v (throw 'error nil)))
-			  (let ((v ($float epsrel)))
-			    (if (numberp v) v (throw 'error nil)))
+			  (float-or-lose epsabs)
+			  (float-or-lose epsrel)
 			  0.0 0.0 0 0
 			  limit lenw 0 iwork work)
 	  (declare (ignore junk z-a z-b z-alfa z-beta z-int z-epsabs z-epsrel
@@ -300,6 +274,40 @@
 	  ((mequal) $epsabs ,epsabs)
 	  ((mequal) $limit ,limit))))))
 
+(defun quad-qagp (fun var a b points
+		  &key (epsrel 1e-8) (epsabs 0.0) (limit 200))
+  (quad_argument_check fun var a b)
+  (let* ((npts2 (+ 2 (length (cdr points))))
+	 (p (make-array npts2 :element-type 'flonum))
+	 (leniw (max limit (- (* 3 npts2) 2)))
+	 (lenw (- (* 2 leniw) npts2))
+	 (work (make-array lenw :element-type 'flonum))
+	 (iwork (make-array limit :element-type 'f2cl-lib:integer4))
+	 (f (get-integrand fun var)))
+    (map-into p #'float-or-lose (cdr points))
+    (handler-case
+	(multiple-value-bind (junk z-a z-b z-npts z-points z-epsabs z-epsrel
+				   result abserr neval ier
+				   z-leniw z-lenw last)
+	    (slatec:dqagp #'(lambda (x)
+			      (float (funcall f x)))
+			  (float-or-lose a)
+			  (float-or-lose b)
+			  npts2
+			  p
+			  (float-or-lose epsabs)
+			  (float-or-lose epsrel)
+			  0.0 0.0 0 0
+			  leniw lenw 0 iwork work)
+	  (declare (ignore junk z-a z-b z-npts z-points z-epsabs z-epsrel
+			   z-leniw z-lenw last))
+	  (list '(mlist) result abserr neval ier))
+      (error ()
+	`(($quad_qagp) ,fun ,var ,a ,b ,points
+	  ((mequal) $epsrel ,epsrel)
+	  ((mequal) $epsabs ,epsabs)
+	  ((mequal) $limit ,limit))))))
+					
 ;; error checking similar to that done by $defint
 (defun quad_argument_check (exp var ll ul) 
   (setq exp (ratdisrep exp))
@@ -315,6 +323,20 @@
 	     (among var ll))
 	 (merror "Limit contains variable of integration: ~M" var))))
 
+(defun quad-control (parameter &optional new-value)
+  (values
+   (slatec:j4save (case parameter
+		    ($current_error 1)
+		    ($control 2)
+		    ($max_message 4)
+		    (otherwise
+		     (merror "Parameter should be current_error, control, or max_mmessage")))
+		  (or new-value 0)
+		  (if new-value t nil))))
+
+(defun $quad_control (parameter &rest new-value)
+  (quad-control parameter (if new-value (car new-value))))
+
 (macrolet
     ((frob (mname iname args valid-keys)
        (let* ((keylist (gensym "KEY-LIST-"))
@@ -332,7 +354,8 @@
   (frob $quad_qawc quad-qawc (fun var c a b) ($epsrel $limit $epsabs))
   (frob $quad_qawf quad-qawf (fun var a omega trig) ($limit $epsabs $maxp1 $limlst))
   (frob $quad_qawo quad-qawo (fun var a b omega trig) ($epsrel $limit $epsabs $maxp1))
-  (frob $quad_qaws quad-qaws (fun var a b alfa beta wfun) ($epsrel $limit $epsabs)))
+  (frob $quad_qaws quad-qaws (fun var a b alfa beta wfun) ($epsrel $limit $epsabs))
+  (frob $quad_qagp quad-qagp (fun var a b points) ($epsrel $limit $epsabs)))
   
 ;; Tests
 ;;
