@@ -170,11 +170,11 @@
 	      (cond ((zerop1 y)
 		     0)
 		    ((equal 1 y)
-		     %pi//2)
+		     (div '$%pi 2))
 		    ((equal -1 y)
-		     (neg %pi//2))
+		     (div '$%pi -2))
 		    ((alike1 y 1//2)
-		     (mul '((rat simp) 1 6) '$%pi))
+		     (div '$%pi 6))
 		    ((alike1 y -1//2)
 		     (div '$%pi -6))
 		    ;; 1/sqrt(2)
@@ -215,16 +215,16 @@
 	((and $%piargs 
 	      ;; Recognize some special values
 	      (cond ((zerop1 y)
-		     %pi//2)
+		     (div '$%pi 2))
 		    ((equal 1 y)
 		     0)
 		    ((equal -1 y)
 		     '$%pi)
 		    ((alike1 y 1//2)
-		     (mul '((rat simp) 1 3) '$%pi))
+		     (div '$%pi 3))
 		    ((alike1 y -1//2)
 		     (mul '$%pi (div 2 3)))
-	    ;; 1/sqrt(2)
+	            ;; 1/sqrt(2)
 		    ((alike1 y (power* 2 -1//2))
 		     (div '$%pi 4))
 		    ;; sqrt(3)/2
@@ -257,8 +257,14 @@
   (cond ((flonum-eval (mop form) y))
 	((and (not (member 'simp (car form))) (big-float-eval (mop form) y)))
 	((taylorize (mop form) (second form)))
-	((and $%piargs
-	      (cond ((zerop1 y) %pi//2) ((equal 1 y) %pi//4) ((equal -1 y) (neg %pi//4)))))
+        ((and $%piargs
+              (cond ((zerop1 y) (div '$%pi 2))
+                    ((equal 1 y) (div '$%pi 4))
+                    ((equal -1 y) (div '$%pi -4))
+                    ;; 1/sqrt(3)
+                    ((alike1 y '((mexpt) 3 ((rat) -1 2))) (div '$%pi 3))
+                    ;; sqrt(3)
+                    ((alike1 y '((mexpt) 3 ((rat) 1 2))) (div '$%pi 6)))))
 	((and $%iargs (multiplep y '$%i)) (mul -1 '$%i (cons-exp '%acoth (coeff y '$%i 1))))
 	((and (not (atom y)) (member (caar y) '(%cot %tan))
 	      (if ($constantp (cadr y))
@@ -284,8 +290,15 @@
   (cond ((flonum-eval (mop form) y))
 	((and (not (member 'simp (car form))) (big-float-eval (mop form) y)))
 	((taylorize (mop form) (second form)))
-	((and $%piargs
-	      (cond ((equal 1 y) %pi//2) ((equal -1 y) (neg %pi//2)))))
+        ((and $%piargs
+              (cond ((equal 1 y) (div '$%pi 2))
+                    ((equal -1 y) (div '$%pi -2))
+                    ((equal y 2) (div '$%pi 6))
+                    ;; sqrt(2)
+                    ((alike1 y '((mexpt) 2 ((rat) 1 2))) (div '$%pi 4))
+                    ;; 2*sqrt(3)/3
+                    ((alike1 y '((mtimes) 2 ((mexpt) 3 ((rat) -1 2))))
+                     (div '$%pi 3)))))
 	((and $%iargs (multiplep y '$%i)) (mul -1 '$%i (cons-exp '%acsch (coeff y '$%i 1))))
 	((and (not (atom y)) (eq '%csc (caar y))
 	      (if ($constantp (cadr y))
@@ -306,8 +319,15 @@
   (cond ((flonum-eval (mop form) y))
 	((and (not (member 'simp (car form))) (big-float-eval (mop form) y)))
 	((taylorize (mop form) (second form)))
-	((and $%piargs 
-	      (cond ((equal 1 y) 0) ((equal -1 y) '$%pi))))
+        ((and $%piargs 
+              (cond ((equal 1 y) 0) 
+                    ((equal -1 y) '$%pi)
+                    ((equal 2 y) (div '$%pi 3))
+                    ;; sqrt(2)
+                    ((alike1 y '((mexpt) 2 ((rat) 1 2))) (div '$%pi 4))
+                    ;; 2/sqrt(3)
+                    ((alike1 y '((mtimes) 2 ((mexpt) 3 ((rat) -1 2))))
+                     (div '$%pi 6)))))
 	((and (not (atom y)) (eq '%sec (caar y))
 	      (if ($constantp (cadr y))
 		  (let ((y-val (mfuncall '$mod (cadr y) (m* 2 '$%pi))))
